@@ -1,3 +1,5 @@
+( cd opt/kde/share/doc/HTML/it/kivio ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kivio ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kword ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kword ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/koffice ; rm -rf common )
@@ -6,6 +8,8 @@
 ( cd opt/kde/share/doc/HTML/it/koshell ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kspread ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kspread ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kchart ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kchart ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/thesaurus ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/thesaurus ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kformula ; rm -rf common )
